#exonware/xwsystem/src/exonware/xwsystem/io/indexing/__init__.py
"""
Company: eXonware.com
Author: Eng. Muhammad AlShehri
Email: connect@exonware.com
Version: 0.1.0.4
Generation Date: January 2026

Indexing module - Unified indexing facade for line-oriented files.
"""

from .facade import XWIndex

__all__ = ["XWIndex"]
