"""
#exonware/xwsystem/src/exonware/xwsystem/defs.py

Package-level definitions (constants, enums, TypedDicts) for xwsystem.

Company: eXonware.com
Author: Eng. Muhammad AlShehri
Email: connect@exonware.com
Version: 0.1.0.4
Last Updated: 29-Jan-2026
"""

from __future__ import annotations


__all__: list[str] = []

